#!/bin/bash -e

usage() {
  echo "About: Uses a Host Factory token to create a host and returns its netrc entry"
  echo "Usage: $0 [-e CONJUR_ENDPOINT] [-t HFTOKEN] [-h HOSTID]"
  echo "Example: $0 -e conjur.myorg.com -t 392x...6tvfgw89 -h ec2/jenkins001"
  echo "---"
  echo "Use $PEMPATH to override the path to your Conjur public key, default: '/etc/conjur-<orgaccount>.pem'"
  exit 1
}

while getopts ":e:t:h:" o; do
  case "${o}" in
    e)
      e=${OPTARG}
      ;;
    t)
      t=${OPTARG}
      ;;
    h)
      h=${OPTARG}
      ;;
    *)
      usage
      ;;
  esac
done

if [ -z "${e}" ] || [ -z "${t}" ] || [ -z "${h}" ]; then
    usage
fi

ENDPOINT=${e}
TOKEN=${t}
HOSTID=${h}

PEMPATH=${PEMPATH:-$(ls /etc/conjur-*.pem)}

curl -s -X POST \
  --cacert $PEMPATH \
  -H "Authorization: Token token=\"$TOKEN\"" \
  "https://$ENDPOINT/api/host_factories/hosts?id=$HOSTID" \
  -o response.json

HOSTFACTORY=$(cat response.json | jq -r .userid | cut -d'/' -f2-)
APIKEY=$(cat response.json | jq -r .api_key)
ORGACCOUNT=$(cat response.json | jq -r .roleid | cut -d':' -f1)

echo "Creating host '$HOSTID' with Host Factory '$HOSTFACTORY'."
echo "Writing identity file."
cat << EOF > conjur.identity
machine https://$ENDPOINT/api/authn
    login host/$HOSTID
    password $APIKEY
EOF

# rm -f response.json
echo "All set, machine has been assigned a Conjur identity."
